@@ -121,8 +121,11 @@ class AIOModel(Model, metaclass=AIOModelBase):
         return ModelInsert(cls, cls._normalize_data(__data, insert))
 
     @classmethod
-    def insert_many(cls, rows, fields=None) -> ModelInsert:
+    def insert_many(cls, rows: t.Sequence, fields=None) -> ModelInsert:
         rows = [row.__data__ if isinstance(row, Model) else row for row in rows]
+        if not rows:
+            raise ModelInsert.DefaultValuesException('Error: no rows to insert.')
+
         return ModelInsert(cls, insert=rows, columns=fields)
 
     @classmethod
